@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: tagged
-version: 0.1.1
-id: tagged-0.1.1-dc7f0ae3232e391c856024a6d3f33a4a
+version: 0.2
+id: tagged-0.2-7caf964ebb614f24b61729c6e1006b72
 
 license: BSD3
-copyright: 2009 Edward A. Kmett
+copyright: 2009-2011 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
 stability: experimental
 homepage: http://github.com/ekmett/tagged
@@ -14,22 +14,22 @@ category: Data, Phantom Types
 author: Edward A. Kmett
 pkgpath: devel/hs-tagged
 exposed: True
-exposed-modules: Data.Tagged
+exposed-modules: Data.Tagged Data.Proxy
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/tagged-0.1.1
-library-dirs: /usr/local/lib/ghc/tagged-0.1.1
-hs-libraries: HStagged-0.1.1
+import-dirs: /usr/local/lib/ghc/tagged-0.2
+library-dirs: /usr/local/lib/ghc/tagged-0.2
+hs-libraries: HStagged-0.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
-         data-default-0.2-57d28f8b332284db5e97499a5703d397
+depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
+         data-default-0.2-c825dd0a44fd1b507d46901df6ee08a0
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-tagged-0.1.1/html/tagged.haddock
-haddock-html: /usr/local/share/doc/hs-tagged-0.1.1/html
+haddock-interfaces: /usr/local/share/doc/hs-tagged-0.2/html/tagged.haddock
+haddock-html: /usr/local/share/doc/hs-tagged-0.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
